use Dpkg::BuildInfo;

$environment_filter = [(sort (map "^$_\$", Dpkg::BuildInfo::get_build_env_allowed())), '^DEB_[A-Z]+_STRIP$'];

$unshare_bind_mounts = [
    {
        directory => $ENV{'CCACHE_HOST_DIR'},
        mountpoint => '/build/ccache',
    },
];

$build_environment = {
    'CCACHE_DIR' => '/build/ccache',
    'CCACHE_MAXSIZE' => $ENV{'CCACHE_MAXSIZE'},
};

$path = '/usr/lib/ccache:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin';
